@@ -116,7 +116,6 @@ static inline G_CONST_RETURN gchar* g_dgettext_localised_or_english (const gchar
 static guint mode_selection_applet_get_selected_radio_access_technology (ModeSelectionApplet *plugin)
 {
 	ModeSelectionAppletPrivate *priv = MODE_SELECTION_APPLET_GET_PRIVATE (plugin);
-	guint retval;
 	guchar network_access;
 	gint some_next_value;
 
@@ -124,9 +123,7 @@ static guint mode_selection_applet_get_selected_radio_access_technology (ModeSel
 
 	dbus_g_proxy_call (priv->phonet_proxy, NETWORK_PATH_GET_RADIO_ACCESS, NULL, G_TYPE_INVALID, G_TYPE_UCHAR, &network_access, G_TYPE_INT, &some_next_value, G_TYPE_INVALID);
 
-	retval = network_access;
-
-	return retval;
+	return (guint) network_access;
 }
 
 static void mode_selection_applet_set_selected_radio_access_technology (ModeSelectionApplet *plugin, const guchar mode)
@@ -146,22 +143,20 @@ static void mode_selection_applet_set_button_value (ModeSelectionApplet *plugin)
 	const guint radio_access = mode_selection_applet_get_selected_radio_access_technology (plugin);
 
 	for (i = 0; i < NUM; i++)
+	{
 		g_signal_handler_block (priv->toggle_button[i], priv->signal_id[i]);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->toggle_button[radio_access]), TRUE);
-
-	for (i = 0; i < NUM; i++)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->toggle_button[radio_access]), TRUE);
 		g_signal_handler_unblock (priv->toggle_button[i], priv->signal_id[i]);
+	}
 }
 
 static void mode_selection_applet_on_button_toggled (GtkToggleButton *button, ModeSelectionApplet *plugin)
 {
 	g_return_if_fail (plugin);
 
-	const guint mode = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (button), "toggled-button-no."));
-
 	if (gtk_toggle_button_get_active (button))
 	{
+		const guint mode = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (button), "toggled-button-no."));
 		GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (button));
 		gtk_widget_hide (toplevel);
 
@@ -169,7 +164,7 @@ static void mode_selection_applet_on_button_toggled (GtkToggleButton *button, Mo
 	}
 }
 
-static void mode_selection_applet_update_on_radio_access_technology_changed (DBusGProxy *object, guchar status G_GNUC_UNUSED, ModeSelectionApplet *plugin)
+static void mode_selection_applet_update_on_radio_access_technology_changed (DBusGProxy *object, const guchar status G_GNUC_UNUSED, ModeSelectionApplet *plugin)
 {
 	g_return_if_fail (plugin);
 
@@ -213,9 +208,10 @@ static void mode_selection_applet_setup_buttons (const guint i, ModeSelectionApp
 	ModeSelectionAppletPrivate *priv = MODE_SELECTION_APPLET_GET_PRIVATE (plugin);
 	g_return_if_fail (priv);
 
-	priv->toggle_button[i] = hildon_gtk_radio_button_new_from_widget (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH, GTK_RADIO_BUTTON (priv->toggle_button[i-1]));
+	priv->toggle_button[i] = !i ? hildon_gtk_radio_button_new (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH, NULL) : hildon_gtk_radio_button_new_from_widget (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH, GTK_RADIO_BUTTON (priv->toggle_button[i-1]));
 	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (priv->toggle_button[i]), FALSE);
 	gtk_button_set_label (GTK_BUTTON (priv->toggle_button[i]), g_dgettext_localised_or_english ("osso-connectivity-ui", items[i].msgid, items[i].fallback_string));
+	gtk_label_set_ellipsize (GTK_LABEL (GTK_BIN (priv->toggle_button[i])->child), PANGO_ELLIPSIZE_END);
 	g_object_set_data (G_OBJECT (priv->toggle_button[i]), "toggled-button-no.", GUINT_TO_POINTER (i));
 	priv->signal_id[i] = g_signal_connect (G_OBJECT (priv->toggle_button[i]), "toggled", G_CALLBACK (mode_selection_applet_on_button_toggled), plugin);
 	gtk_container_add (GTK_CONTAINER (priv->hbox_applet_contents), priv->toggle_button[i]);
